@@ -2,16 +2,16 @@
 # -*- coding: utf-8 -*-
 '''
 Filename: kfzcheck.py
-Version: 1.5
-last change: 2010-03-13
+Version: 1.6
+last change: 2010-03-15
 Function: KFZcheck is a small program written in python and uses the gtk toolkit. 
 It searches for car (in german kfz) license plates shortcuts and the citys according to the 
 searchword - german example: S for Stuttgart. 
 
 Copyright (C) 2010 Patrick Beck <pbeck at yourse dot de>  
 
-I have to thanks Bartholomäus Wlako for the created austrian country package and his 
-help to find a bug with the picture creation :)
+I have to thanks Bartholomäus Wlako for the created austrian and poland country package and his 
+help to find a bug with the picture creation and the improvement of the search engine :)
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -123,7 +123,6 @@ class Kfzcheck(object):
     def search(self, widget=None, entry=None, country=None):
         self.deletecolumn() # delete the whole column before you add new items
         self.count_rows = 0 # for top, middle, bottom scrolling    
-        self.top.set_active(True) # set the Top filter button active (because we are at the top)
         try:
             searchword = unicode(entry.get_text(), 'utf-8')
         except AttributeError:
@@ -136,21 +135,28 @@ class Kfzcheck(object):
                 row[0] = unicode(row[0], 'utf-8') # unicode for äöü
                 row[1] = unicode(row[1], 'utf-8')
                 
-                if searchtext.upper() in row: # search for the shortcut (not casesensitive)
-                    store_items.clear() 
+                if re.match(searchtext, row[0]) != None: # if uppercase searchtext show all license plates thats starts with searchtext
                     try:
                         self.searchdata(row[0], row[1], store_items, row[2])
                     except IndexError:
                         self.searchdata(row[0], row[1], store_items)
-                        
-                    break # when the shortcut matches exactly => break the loop
                 else:
-                    if re.match(searchtext, row[1], re.IGNORECASE) != None: # search for the city (not casesensitive)
-                        try:
-                            self.searchdata(row[0], row[1], store_items, row[2])
-                        except IndexError:
-                            self.searchdata(row[0], row[1], store_items)
-            
+                    if searchtext.islower():
+                        if searchtext.upper() in row: # search for the license plate and show only the right (not casesensitive)
+                            store_items.clear() 
+                            try:
+                                self.searchdata(row[0], row[1], store_items, row[2])
+                            except IndexError:
+                                self.searchdata(row[0], row[1], store_items)
+                        
+                            break # when the shortcut matches exactly => break the loop
+                        else:
+                            if re.match(searchtext, row[1], re.IGNORECASE) != None: # search for the city (not casesensitive)
+                                try:
+                                    self.searchdata(row[0], row[1], store_items, row[2])
+                                except IndexError:
+                                    self.searchdata(row[0], row[1], store_items)
+                     
             try: # display a message when no results are found
                 store_items[0] # it raises a error when no items stored
             except IndexError:    
@@ -205,12 +211,11 @@ class Kfzcheck(object):
 
     def about(self, widget):
         about = gtk.AboutDialog()
-        about.set_program_name("KFZcheck")
-        about.set_version("1.5")
-        about.set_copyright("(c) Patrick Beck")
-        about.set_comments(_("KFZcheck searches for kfz license plates shortcuts and citys - german example: S for Stuttgart. A german, austrian and swiss list is included")) 
-        about.set_website("http://wiki.yourse.de/doku.php?id=python:kfzcheck")
-        about.set_logo(gtk.gdk.pixbuf_new_from_file("/usr/share/pixmaps/kfzcheck.png"))
+        about.set_program_name('KFZcheck')
+        about.set_version('1.6')
+        about.set_comments(_("KFZcheck searches for kfz license plates shortcuts and citys / regions. Uppercase searches for all license plates starting with your search. Lowercase matches exactly for the license plates and searches after the city / region if no license plate exists.")) 
+        about.set_website('http://wiki.yourse.de/doku.php?id=python:kfzcheck')
+        about.set_logo(gtk.gdk.pixbuf_new_from_file('/usr/share/pixmaps/kfzcheck.png'))
         about.run()
         about.destroy()
     
@@ -223,7 +228,6 @@ class Kfzcheck(object):
         self.Config.write(ini_file) # write and save it
         ini_file.close # close the ini file
         self.entry.set_text('') # set the entry field to nothing when the country field changed
-        self.top.set_active(True) # set the Top filter button active (because we are at the top)
 
     def filter(self, button, label):
         if label == 'Top':
@@ -277,13 +281,13 @@ class Kfzcheck(object):
         self.menu.add_filter(self.top)
         self.top.set_mode(False)
 
-        self.middle = hildon.GtkRadioButton(gtk.HILDON_SIZE_AUTO, self.top)
+        self.middle = hildon.GtkRadioButton(gtk.HILDON_SIZE_AUTO, None)
         self.middle.set_label(_('Middle'))
         self.middle.connect("clicked", self.filter, 'Middle')
         self.menu.add_filter(self.middle)
         self.middle.set_mode(False)
         
-        self.bottom = hildon.GtkRadioButton(gtk.HILDON_SIZE_AUTO, self.middle)
+        self.bottom = hildon.GtkRadioButton(gtk.HILDON_SIZE_AUTO, None)
         self.bottom.set_label(_('Bottom'))
         self.bottom.connect("clicked", self.filter, 'Bottom')
         self.menu.add_filter(self.bottom)
@@ -320,7 +324,7 @@ class Kfzcheck(object):
 
         main_window = self.window   # auto rotate function by thp
         app_name = 'kfzcheck'
-        app_version = '1.5'
+        app_version = '1.6'
         initial_mode = portrait.FremantleRotation.AUTOMATIC
         rotation_object = portrait.FremantleRotation(app_name, main_window, app_version, initial_mode)
 
